Module registry

Module registry 

Enums

RegistryError
Errors that can occur when registering a value in the registry.

Functions

register
Register a value by name in the global registry.
registered
List all registered names.
unregister
Remove a registration by name. No-op if the name is not registered.
whereis
Look up a value by name. Returns None if not found or if the stored type doesn’t match T.